==> react-chat-app-0.1.8.tgz: package/lib/esm/index.js <==
import { A as AvatarWrapper, a as Avatar } from './index-6c87b21f.js';
export { a as Avatar } from './index-6c87b21f.js';
import Badge from './Badge.js';
export { default as Badge } from './Badge.js';
export { default as Bubble } from './Bubble.js';
export { B as Button } from './index-90993595.js';
import { _ as _extends } from './_rollupPluginBabelHelpers-1b8c042f.js';
import React__default from 'react';
import { Y as Ye, _ as _e, L as Le, p as propTypes } from './styled-components.esm-daf9ff3f.js';
import { t as theme } from './theme-b7be7677.js';
import { S as StyledParagraph, P as Paragraph } from './index-165cbcf7.js';
export { P as Paragraph } from './index-165cbcf7.js';
import { I as Icon } from './index-5c904739.js';
export { I as Icon } from './index-5c904739.js';
import { b as card, a as activeBar } from './mixins-dcc08a2b.js';
import Text from './Text.js';
export { default as Text } from './Text.js';
export { default as Divider } from './Divider.js';
export { default as Filter } from './Filter.js';
export { default as Heading } from './Heading.js';
export { default as Input } from './Input.js';
export { default as MessageBar } from './MessageBar.js';
export { default as Navbar } from './Navbar.js';
export { default as Option } from './Option.js';
export { default as Popover } from './Popover.js';
export { default as Select } from './Select.js';
export { default as VoiceMessage } from './VoiceMessage.js';
import './style-03e893cd.js';

const Title = Ye(Text)`
  grid-area: title;
`;
const RightLabel = Ye(Text)`
  grid-area: label;
  justify-self: end;
`;
const SubTitle = Ye(Text)`
  grid-area: subtitle;
`;
const Description = Ye.div`
  grid-area: description;
  display: grid;
  grid-template-columns: 1fr 30px;
  ${iconSvg => iconSvg && _e`
  grid-template-columns: 24px 1fr 30px;
  `}
  align-items: center;

`;
const UnreadBadge = Ye(Badge)`
  justify-self: end;
`;
const StyledCard = Ye.div`
  ${card()};
  display: grid;
  grid-template-areas:
    "avatar title label"
    "avatar subtitle sublabel"
    "description description description";
  grid-template-columns: 24px 1fr 1fr;
  row-gap: 16px;
  background: ${({
  background
}) => background};
  transition: 0.4s;
  &:hover {
    box-shadow: 0px 20px 50px rgba(0, 0, 0, 0.1);
  }

  ${AvatarWrapper} {
    grid-area: avatar;
  }

  ${({
  active
}) => active && _e`
      background: ${({
  theme
}) => theme.darkPurple};
      ${Title}, ${SubTitle}, ${RightLabel}, ${StyledParagraph} {
        color: white;
      }
      ${SubTitle}, ${RightLabel} {
        opacity: 0.4;
      }
      ${activeBar({
  barWidth: '4px',
  shadowWidth: '14px'
})}
      overflow: hidden;`}
`;

function Card({
  children,
  background = '#fff',
  avatarUrl,
  avatarStatus,
  title,
  subtitle,
  rightLabel,
  subLabel: SubLabel,
  description,
  count,
  active,
  iconSvg,
  ...rest
}) {
  return /*#__PURE__*/React__default.createElement(Le, {
    theme: theme
  }, /*#__PURE__*/React__default.createElement(StyledCard, _extends({
    active: active
  }, rest, {
    background: background
  }), /*#__PURE__*/React__default.createElement(Avatar, {
    status: avatarStatus,
    src: avatarUrl
  }), /*#__PURE__*/React__default.createElement(Title, null, title), /*#__PURE__*/React__default.createElement(SubTitle, null, subtitle), SubLabel && /*#__PURE__*/React__default.createElement(SubLabel, {
    style: {
      'grid-area': sublabel
    }
  }), /*#__PURE__*/React__default.createElement(RightLabel, null, rightLabel), /*#__PURE__*/React__default.createElement(Description, {
    iconSvg: iconSvg
  }, iconSvg && /*#__PURE__*/React__default.createElement(Icon, {
    width: 16,
    height: 14,
    icon: iconSvg,
    color: active ? theme.inactiveColorDark : theme.inactiveColor,
    opacity: active ? 0.4 : 1,
    style: {
      justifyContent: 'start'
    }
  }), /*#__PURE__*/React__default.createElement(Paragraph, null, description), /*#__PURE__*/React__default.createElement(UnreadBadge, {
    count: count
  }))));
}

Card.propTypes = {
  children: propTypes.any,
  background: propTypes.string,
  avatarUrl: propTypes.string,
  title: propTypes.string,
  subtitle: propTypes.string,
  rightLabel: propTypes.string,
  subLabel: propTypes.element,
  description: propTypes.string,
  count: propTypes.number,
  avatarStatus: propTypes.any,
  active: propTypes.bool,
  iconSvg: propTypes.oneOfType([propTypes.func, propTypes.object])
};

export { Card };

==> react-chat-app-0.1.9.tgz: package/lib/esm/index.js <==
import Avatar from './Avatar.js';
export { default as Avatar } from './Avatar.js';
export { default as Badge } from './Badge.js';
export { default as Bubble } from './Bubble.js';
export { B as Button } from './index-d7bca72b.js';
import { _ as _extends } from './_rollupPluginBabelHelpers-1b8c042f.js';
import React__default from 'react';
import { L as Le, p as propTypes } from './styled-components.esm-a60371c1.js';
import { t as theme } from './theme-e593c2e7.js';
import Paragraph from './Paragraph.js';
export { default as Paragraph } from './Paragraph.js';
import { I as Icon } from './index-3c33a3b3.js';
export { I as Icon } from './index-3c33a3b3.js';
import { S as StyledCard, T as Title, a as SubTitle, R as RightLabel, D as Description, U as UnreadBadge } from './index-11bab19a.js';
export { M as MessageList } from './index-11bab19a.js';
export { default as Divider } from './Divider.js';
export { default as Filter } from './Filter.js';
export { default as Heading } from './Heading.js';
export { default as Input } from './Input.js';
export { default as MessageBar } from './MessageBar.js';
export { MenuItem, default as Navbar } from './Navbar.js';
export { default as Option } from './Option.js';
export { default as Popover } from './Popover.js';
export { default as Select } from './Select.js';
export { default as Text } from './Text.js';
export { default as VoiceMessage } from './VoiceMessage.js';
export { default as Profile } from './Profile.js';
export { default as DropDown } from './DropDown.js';
export { default as TitleBar } from './TitleBar.js';
export { default as FilterList } from './FilterList.js';
import ChatApp from './ChatApp.js';
export { default } from './ChatApp.js';
export { default as Conversation } from './Conversation.js';
import './style-07254a25.js';
import './mixins-b7fe34bc.js';
import './style-d40a0211.js';
import './style-fb8054ef.js';
import './style-85ec59ca.js';
import './index-2aec7d0d.js';

function Card({
  children,
  background = '#fff',
  avatarUrl,
  avatarStatus,
  title,
  subtitle,
  rightLabel,
  subLabel: SubLabel,
  description,
  count,
  active,
  iconSvg,
  ...rest
}) {
  return /*#__PURE__*/React__default.createElement(Le, {
    theme: theme
  }, /*#__PURE__*/React__default.createElement(StyledCard, _extends({
    active: active
  }, rest, {
    background: background
  }), /*#__PURE__*/React__default.createElement(Avatar, {
    status: avatarStatus,
    src: avatarUrl
  }), /*#__PURE__*/React__default.createElement(Title, null, title), /*#__PURE__*/React__default.createElement(SubTitle, null, subtitle), SubLabel && /*#__PURE__*/React__default.createElement(SubLabel, {
    style: {
      'grid-area': 'sublabel'
    }
  }), /*#__PURE__*/React__default.createElement(RightLabel, null, rightLabel), /*#__PURE__*/React__default.createElement(Description, {
    iconSvg: iconSvg
  }, iconSvg && /*#__PURE__*/React__default.createElement(Icon, {
    width: 16,
    height: 14,
    icon: iconSvg,
    color: active ? theme.inactiveColorDark : theme.inactiveColor,
    opacity: active ? 0.4 : 1,
    style: {
      justifyContent: 'start'
    }
  }), /*#__PURE__*/React__default.createElement(Paragraph, null, description), /*#__PURE__*/React__default.createElement(UnreadBadge, {
    count: count
  }))));
}

Card.propTypes = {
  children: propTypes.any,
  background: propTypes.string,
  avatarUrl: propTypes.string,
  title: propTypes.string,
  subtitle: propTypes.string,
  rightLabel: propTypes.string,
  subLabel: propTypes.element,
  description: propTypes.string,
  count: propTypes.number,
  avatarStatus: propTypes.any,
  active: propTypes.bool,
  iconSvg: propTypes.oneOfType([propTypes.func, propTypes.object])
};

export { Card };
